# Common utilities for Jutge.org's scripts

This is just a package to share common utilities used
in different Python scripts of Jutge.org.


## Credits

- Jordi Petit (https://github.com/jordi-petit)
- Jordi Reig (https://github.com/jordireig)


## License

Apache License 2.0
